import wx

import GradientButton as GB

# Simple log class...
class MyLog(wx.PyLog):
    def __init__(self, textCtrl, logTime=0):
        wx.PyLog.__init__(self)
        self.tc = textCtrl
        self.logTime = logTime

    def DoLogString(self, message, timeStamp):
        if self.tc:
            self.tc.AppendText(message + '\n')

            
class GradientButtonDemo(wx.Frame):

    def __init__(self, parent, id=wx.ID_ANY, title="", pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE):

        wx.Frame.__init__(self, parent, id, title, pos, size, style)

        self.mainPanel = wx.Panel(self)
        
        # Initialize GradientButton 1 (no image)
        self.btn1 = GB.GradientButton(self.mainPanel, -1, None, "Hello World!")
        # Initialize GradientButton 2 (with image)
        bitmap = wx.Bitmap("button.png", wx.BITMAP_TYPE_PNG)
        self.btn2 = GB.GradientButton(self.mainPanel, -1, bitmap, "GradientButton")

        self.topStartColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetTopStartColour(),
                                                  name="Top Start")
        self.topEndColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetTopEndColour(),
                                                name="Top End")
        self.bottomStartColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetBottomStartColour(),
                                                     name="Bottom Start")
        self.bottomEndColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetBottomEndColour(),
                                                   name="Bottom End")
        self.pressedTopColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetPressedTopColour(),
                                                    name="Pressed Top")
        self.pressedBottomColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetPressedBottomColour(),
                                                       name="Pressed Bottom")
        self.textColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetForegroundColour(),
                                              name="Text Colour")

        # Set up a log window
        self.log = wx.TextCtrl(self.mainPanel, -1, size=(-1, 150),
                               style = wx.TE_MULTILINE|wx.TE_READONLY|wx.HSCROLL)
        if wx.Platform == "__WXMAC__":
            self.log.MacCheckSpelling(False)
            
        # But instead of the above we want to show how to use our own wx.Log class
        wx.Log_SetActiveTarget(MyLog(self.log))
        
        self.CreateMenuBar()

        self.SetProperties()
        self.DoLayout()
        self.BindEvents()
        
        self.CenterOnScreen()
        self.Show()
        

    def CreateMenuBar(self):

        menuBar = wx.MenuBar(wx.MB_DOCKABLE)
        fileMenu = wx.Menu()
        helpMenu = wx.Menu()
        
        item = wx.MenuItem(fileMenu, wx.ID_ANY, "E&xit", "Exit demo")
        self.Bind(wx.EVT_MENU, self.OnClose, item)
        fileMenu.AppendItem(item)

        item = wx.MenuItem(helpMenu, wx.ID_ANY, "About...", "Shows The About Dialog")
        self.Bind(wx.EVT_MENU, self.OnAbout, item)
        helpMenu.AppendItem(item)
        
        menuBar.Append(fileMenu, "&File")
        menuBar.Append(helpMenu, "&Help")

        self.SetMenuBar(menuBar)


    def SetProperties(self):        

        self.SetTitle("GradientButton wxPython Demo ;-)")
        self.SetIcon(wx.Icon("wxpdemo.ico", wx.BITMAP_TYPE_ICO))
        self.log.write("Log Window\n\n")


    def DoLayout(self):

        frameSizer = wx.BoxSizer(wx.VERTICAL)
        mainSizer = wx.BoxSizer(wx.VERTICAL)
        btnSizer = wx.BoxSizer(wx.HORIZONTAL)        
        colourSizer = wx.FlexGridSizer(4, 4, 1, 10)

        label1 = wx.StaticText(self.mainPanel, -1, "Welcome to the GradientButton demo for wxPython!")        
        mainSizer.Add(label1, 0, wx.EXPAND|wx.LEFT|wx.RIGHT|wx.TOP, 10)

        mainSizer.Add(self.btn1, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT|wx.RIGHT|wx.TOP, 15)
        btnSizer.Add(self.btn2, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5)
        btnSizer.Add((20, 0))

        firstStrings = ["Top Start", "Bottom Start", "Pressed Top", "Text Colour"]
        secondStrings = ["Top End", "Bottom End", "Pressed Bottom", ""]
        
        for strings in firstStrings:
            label = wx.StaticText(self.mainPanel, -1, strings)
            colourSizer.Add(label, 0, wx.ALIGN_CENTER|wx.EXPAND)
        for strings in firstStrings:
            colourSizer.Add(self.FindWindowByName(strings), 0, wx.ALIGN_CENTER|wx.BOTTOM|wx.EXPAND, 10)

        for strings in secondStrings:
            label = wx.StaticText(self.mainPanel, -1, strings)
            colourSizer.Add(label, 0, wx.ALIGN_CENTER|wx.EXPAND)
        for strings in secondStrings[:-1]:
            colourSizer.Add(self.FindWindowByName(strings), 0, wx.ALIGN_CENTER|wx.EXPAND, 10)

        btnSizer.Add(colourSizer, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL)
        btnSizer.Add((10, 0))
        mainSizer.Add(btnSizer, 0, wx.EXPAND|wx.ALL, 10)

        boldFont = wx.SystemSettings_GetFont(wx.SYS_DEFAULT_GUI_FONT)
        boldFont.SetWeight(wx.BOLD)
        
        for child in self.mainPanel.GetChildren():
            if isinstance(child, wx.StaticText):
                child.SetFont(boldFont)

        buttonFont = wx.SystemSettings_GetFont(wx.SYS_DEFAULT_GUI_FONT)
        buttonFont.SetWeight(wx.BOLD)
        try:
            buttonFont.SetFaceName("Tahoma")
            self.btn1.SetFont(buttonFont)
            self.btn2.SetFont(buttonFont)
        except:
            self.btn1.SetFont(boldFont)
            self.btn2.SetFont(boldFont)
            
        mainSizer.Add(self.log, 1, wx.EXPAND|wx.ALL, 5)
        
        self.mainPanel.SetSizer(mainSizer)
        mainSizer.Layout()
        frameSizer.Add(self.mainPanel, 1, wx.EXPAND)
        self.SetSizer(frameSizer)
        frameSizer.Layout()
        self.Fit()
        frameSizer.SetSizeHints(self)


    def BindEvents(self):

        self.Bind(wx.EVT_CLOSE, self.OnClose)
        self.Bind(wx.EVT_COLOURPICKER_CHANGED, self.OnPickColour)
        self.Bind(wx.EVT_BUTTON, self.OnButton, self.btn1)
        self.Bind(wx.EVT_BUTTON, self.OnButton, self.btn2)


    def OnPickColour(self, event):

        obj = event.GetEventObject()
        colour = event.GetColour()
        name = obj.GetName()

        if obj == self.textColour:
            self.btn2.SetForegroundColour(colour)
        else:
            method = "Set%sColour"%(name.replace(" ", ""))
            method = getattr(self.btn2, method)
            method(colour)

            
    def OnClose(self, event):

        wx.CallAfter(self.Destroy)


    def OnButton(self, event):

        obj = event.GetEventObject()
        self.log.write("You clicked %s\n"%obj.GetLabel())


    def OnAbout(self, event):

        msg = "This is the about dialog of GradientButton demo.\n\n" + \
              "Author: Andrea Gavana @ 07 Oct 2008\n\n" + \
              "Please report any bugs/requests of improvements\n" + \
              "to me at the following addresses:\n\n" + \
              "andrea.gavana@gmail.com\n" + "gavana@kpo.kz\n\n" + \
              "Welcome to wxPython " + wx.VERSION_STRING + "!!"
              
        dlg = wx.MessageDialog(self, msg, "GradientButton wxPython Demo",
                               wx.OK | wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()        

        
app = wx.PySimpleApp()
frame = GradientButtonDemo(None, size=(700, 500))
app.MainLoop()

